@@ -12,7 +12,6 @@ from accounts.account import Account
 from accounts.get_accounts import GetAccounts
 from accounts.save_accounts import save_accounts
 from app.app_main import app_tigger
-from app.app_main import apps_starter
 from blockchain.block.blocks_hash import GetBlockshash
 from blockchain.block.blocks_hash import SaveBlockshash
 from blockchain.block.blocks_hash import SaveBlockshash_part
@@ -21,10 +20,9 @@ from blockchain.block.save_block_to_blockchain_db import \
 from config import TEMP_BLOCK_PATH
 from consensus.consensus_main import consensus_trigger
 from lib.config_system import get_config
-from lib.mixlib import dprint
+from lib.log import get_logger
 from lib.perpetualtimer import perpetualTimer
-from node.unl import get_as_node_type
-from node.unl import get_unl_nodes
+from node.unl import Unl
 from transactions.pending_to_validating import PendinttoValidating
 from transactions.save_to_my_transaction import SavetoMyTransaction
 from wallet.wallet import PrivateKey
@@ -32,6 +30,8 @@ from wallet.wallet import PublicKey
 from wallet.wallet import Signature
 from wallet.wallet import Wallet_Import
 
+logger = get_logger("BLOCKCHAIN")
+
 
 class Block:
     """
@@ -42,7 +42,11 @@ class Block:
     own all the coins.
     """
 
-    def __init__(self, creator, previous_hash="0"):
+    def __init__(
+        self,
+        creator,
+        previous_hash="fb8b69c2276c8316c64a5d34b5f3063d1f8b8dc17cda7ee84fa1343978d464a9",
+    ):
         self.genesis_time = int(time.time())
         self.start_time = int(time.time())
         self.block_time = 7
@@ -100,8 +104,9 @@ class Block:
         self.dowload_true_block = ""
 
         self.save_block()
+
+        logger.info("Consensus timer is started")
         perpetualTimer(self.consensus_timer, consensus_trigger).start()
-        apps_starter()
 
     def reset_the_block(self):
         """
@@ -138,17 +143,6 @@ class Block:
 
         self.block_time = self.raund_1_time + self.raund_2_time
 
-        # Printing validated block.
-        dprint("""\n
-  _____                          _     ____  _      ____   _____ _  __
- / ____|                        | |   |  _ \| |    / __ \ / ____| |/ /
-| |    _   _ _ __ _ __ ___ _ __ | |_  | |_) | |   | |  | | |    | ' /
-| |   | | | | '__| '__/ _ \ '_ \| __| |  _ <| |   | |  | | |    |  <
-| |___| |_| | |  | | |  __/ | | | |_  | |_) | |___| |__| | |____| . \
- \_____\__,_|_|  |_|  \___|_| |_|\__| |____/|______\____/ \_____|_|\_\
-
-        """ + str(self.__dict__) + "\n")
-
         self.start_time = int(time.time())
 
         self.raund_1_starting_time = None
@@ -162,7 +156,7 @@ class Block:
         self.validated = False
 
         # Resetting the node candidate blocks.
-        for node in get_as_node_type(get_unl_nodes()):
+        for node in Unl.get_as_node_type(Unl.get_unl_nodes()):
             node.candidate_block = None
             node.candidate_block_hash = None
 
@@ -187,19 +181,15 @@ class Block:
             self.validating_list = []
             self.hash = None
 
-            # Printing new block.
-            dprint("""\n
-    _   _                 ____  _      ____   _____ _  __
-    | \ | |               |  _ \| |    / __ \ / ____| |/ /
-    |  \| | _____      __ | |_) | |   | |  | | |    | ' /
-    | . ` |/ _ \ \ /\ / / |  _ <| |   | |  | | |    |  <
-    | |\  |  __/\ V  V /  | |_) | |___| |__| | |____| . \
-    |_| \_|\___| \_/\_/   |____/|______\____/ \_____|_|\_\
-
-            """ + str(self.__dict__) + "\n")
+            logger.info("New block created")
         else:
+            logger.info(
+                "New block not created because any transaction is not validated"
+            )
             self.empty_block_number += 1
 
+        logger.debug(self.__dict__)
+
         # Adding self.pendingTransaction to the new/current block.
         PendinttoValidating(self)
 
